==> js-api-creator-1.0.5.tgz: package/src/apiCreator.js <==
import requestAPI from './xhrApi';

let isFormData = (payload)=>{
	
	if(typeof FormData !== "undefined" && payload)
	{
		return payload.constructor == new FormData().constructor
	}	
	
	return typeof payload == "function";
}

let Builder = (apiJson, options) => {
	//Url and param builder..
	var apiOptions = (_method='', requestUrl='', parameters={}, queryParameters={}) => {
		
		var userParams = parameters;
		var isFormDataParams = isFormData(parameters);
		if( !isFormDataParams ){
			userParams = Object.assign({}, parameters); // to address re-back call ajax parameters keeping..
			if (Object.keys(parameters).length) {
				var propsToUrl = requestUrl.split('/'); // helps to some parameter to url...
				for (var i = 0, len = propsToUrl.length; i < len; i++) {
					var prop = propsToUrl[i];
					var paramKey = prop.replace(':','');
					if ( prop.charAt(0) === ':' && userParams.hasOwnProperty(paramKey) ) {
						var value = userParams[paramKey];
						requestUrl = requestUrl.replace('/' + prop, value ? '/' + value : '');
						requestUrl = requestUrl.replace( prop + '/', value ? value + '/' : '');
						delete userParams[paramKey];
					}
				}
			}
		}
		
		let defaultParams = Object.assign( {}, queryParameters, options.defaultParams(_method));
		let gobalParamsToUrl = '';
		let count = 0;
		for (var prop in defaultParams) {
			if (count > 0) {
				gobalParamsToUrl += `&${prop}=${defaultParams[prop]}`;
				break;
			}
			gobalParamsToUrl += `${prop}=${defaultParams[prop]}`;
			count = 1;
		}

		gobalParamsToUrl = gobalParamsToUrl ? '?' + gobalParamsToUrl : '';
		
		if( !isFormDataParams ){
			var length = userParams ? Object.keys(userParams).length : 0;
			userParams =  length > 0 ? userParams : null;
		}
		 
		return {
			url: options.prefixUrl(_method) + requestUrl + gobalParamsToUrl, 
			param:userParams
		};
	};

	//url - bind arguments not from user..
	var httpConnection = ajaxmethod => {
		return (url, ajaxoptions={}, ajaxoption2, ajaxoption3 ) => {
			
			let urlHeaders = typeof options.authHeaders === "function" ? options.authHeaders(ajaxmethod) : null;
			if( typeof ajaxoptions === "function" || typeof ajaxoption2 === "function" ){
				
				let success = (typeof ajaxoptions === "function") ? ajaxoptions : ajaxoption2;
				let failure = (typeof ajaxoptions === "function") ? ajaxoption2 : ajaxoption3;
				let payload = (typeof ajaxoptions === "function") ? null : ajaxoptions;
				
				let apioptions = apiOptions(ajaxmethod, url, (payload||{}));
				return requestAPI(apioptions.url,urlHeaders)[ajaxmethod](apioptions.param, progressReport).then(success, failure);
			}
			
			let { payload, headers, parameters, success, failure, progressReport } = ajaxoptions; 
			urlHeaders = urlHeaders ? Object.assign(urlHeaders,headers) : headers; // Override headers
			
			let apioptions = apiOptions(ajaxmethod, url, (payload||{}), parameters);
			return requestAPI(apioptions.url,urlHeaders)[ajaxmethod](apioptions.param, progressReport).then(success, failure);
			
		};
	};

	//auto api functions creation...
	var userAPIS = {};
	for (var prop in apiJson) {
		
		var api = prop;
		var apivalue = apiJson[prop];
		
		var apiurl = apivalue.url;
		var apimethod = apivalue.method;
	
		//var apiFragments = api.split('/');
		var apiFragments = api.split('.');
		var lastObj = userAPIS;

		for (var j = 0; j < apiFragments.length; j++) {
			var apiFragment = apiFragments[j];
			if (apiFragment.indexOf(':') != -1) {
				continue; //Skipping this !api
			}

			if (apiFragment && typeof lastObj[apiFragment] === 'undefined') {
				lastObj[apiFragment] = httpConnection(apimethod).bind(null, apiurl);
			}
			
			if( apiFragment && typeof lastObj[apiFragment] !== 'undefined'){
				lastObj = lastObj[apiFragment];
			}
		}
	}

	return userAPIS;
};

export default class {
	
	constructor(prefixUrl, defaultParams, authHeaders) {
		this.prefixUrl = prefixUrl;
		this.defaultParams = defaultParams;
		this.authHeaders = authHeaders;
	}
	
	create(javaApiList, name) {
		
		let defaultParams = this.defaultParams ? this.defaultParams.bind(null,name) : null;
		let prefixUrl = this.prefixUrl ? this.prefixUrl.bind(null,name) : '';
		let authHeaders = this.authHeaders ? this.authHeaders.bind(null,name) : null;
		
		return Builder(javaApiList || {}, { defaultParams, prefixUrl, authHeaders });
	}
}

==> js-api-creator-1.0.6.tgz: package/src/apiCreator.js <==
import requestAPI from './xhrApi';

let isFormData = (payload)=>{
	
	if(typeof FormData !== "undefined")
	{
		return payload.constructor == new FormData().constructor
	}	
	
	return typeof payload == "function";
}

let Builder = (apiJson, options) => {
	//Url and param builder..
	var apiOptions = (_method='', requestUrl='', parameters={}, queryParameters={}) => {
		
		var isFormDataFound = isFormData(parameters);
		
	    var userParamsClone = Object.assign({}, (isFormDataFound ? queryParameters : parameters) ); // to address re-back call ajax parameters keeping..
		if (Object.keys(userParamsClone).length) {
			var propsToUrl = requestUrl.split('/'); // helps to some parameter to url...
			for (var i = 0, len = propsToUrl.length; i < len; i++) {
				var prop = propsToUrl[i];
				var paramKey = prop.replace(':','');
				if ( prop.charAt(0) === ':' && userParamsClone.hasOwnProperty(paramKey) ) {
					var value = userParamsClone[paramKey];
					requestUrl = requestUrl.replace('/' + prop, value ? '/' + value : '');
					requestUrl = requestUrl.replace( prop + '/', value ? value + '/' : '');
					delete userParamsClone[paramKey];
				}
			}
		}
		
		let userParams = isFormDataFound ? parameters : userParamsClone;
	    queryParameters = isFormDataFound ? userParamsClone : queryParameters;
		
		
		let defaultParams = Object.assign( {}, queryParameters, options.defaultParams(_method));
		let gobalParamsToUrl = '';
		let count = 0;
		for (var prop in defaultParams) {
			if (count > 0) {
				gobalParamsToUrl += `&${prop}=${defaultParams[prop]}`;
				break;
			}
			gobalParamsToUrl += `${prop}=${defaultParams[prop]}`;
			count = 1;
		}

		gobalParamsToUrl = gobalParamsToUrl ? '?' + gobalParamsToUrl : '';
		
		if( !isFormDataFound ){
			var length = userParams ? Object.keys(userParams).length : 0;
			userParams =  length > 0 ? userParams : null;
		}
		 
		return {
			url: options.prefixUrl(_method) + requestUrl + gobalParamsToUrl, 
			param:userParams
		};
	};

	//url - bind arguments not from user..
	var httpConnection = ajaxmethod => {
		return (url, ajaxoptions={}, ajaxoption2, ajaxoption3 ) => {
			
			let urlHeaders = typeof options.authHeaders === "function" ? options.authHeaders(ajaxmethod) : null;
			if( typeof ajaxoptions === "function" || typeof ajaxoption2 === "function" ){
				
				let success = (typeof ajaxoptions === "function") ? ajaxoptions : ajaxoption2;
				let failure = (typeof ajaxoptions === "function") ? ajaxoption2 : ajaxoption3;
				let payload = (typeof ajaxoptions === "function") ? null : ajaxoptions;
				
				let apioptions = apiOptions(ajaxmethod, url, payload);
				return requestAPI(apioptions.url,urlHeaders)[ajaxmethod](apioptions.param, progressReport).then(success, failure);
			}
			
			let { payload={}, headers, parameters, success, failure, progressReport } = ajaxoptions; 
			urlHeaders = urlHeaders ? Object.assign(urlHeaders,headers) : headers; // Override headers
			
			let apioptions = apiOptions(ajaxmethod, url, payload, parameters);
			return requestAPI(apioptions.url,urlHeaders)[ajaxmethod](apioptions.param, progressReport).then(success, failure);
			
		};
	};

	//auto api functions creation...
	var userAPIS = {};
	for (var prop in apiJson) {
		
		var api = prop;
		var apivalue = apiJson[prop];
		
		var apiurl = apivalue.url;
		var apimethod = apivalue.method;
	
		//var apiFragments = api.split('/');
		var apiFragments = api.split('.');
		var lastObj = userAPIS;

		for (var j = 0; j < apiFragments.length; j++) {
			var apiFragment = apiFragments[j];
			if (apiFragment.indexOf(':') != -1) {
				continue; //Skipping this !api
			}

			if (apiFragment && typeof lastObj[apiFragment] === 'undefined') {
				lastObj[apiFragment] = httpConnection(apimethod).bind(null, apiurl);
			}
			
			if( apiFragment && typeof lastObj[apiFragment] !== 'undefined'){
				lastObj = lastObj[apiFragment];
			}
		}
	}

	return userAPIS;
};

export default class {
	
	constructor(prefixUrl, defaultParams, authHeaders) {
		this.prefixUrl = prefixUrl;
		this.defaultParams = defaultParams;
		this.authHeaders = authHeaders;
	}
	
	create(javaApiList, name) {
		
		let defaultParams = this.defaultParams ? this.defaultParams.bind(null,name) : null;
		let prefixUrl = this.prefixUrl ? this.prefixUrl.bind(null,name) : '';
		let authHeaders = this.authHeaders ? this.authHeaders.bind(null,name) : null;
		
		return Builder(javaApiList || {}, { defaultParams, prefixUrl, authHeaders });
	}
}
